//mapping from entity kind to entity base endpoint location
const entityKindMap = {
  'D': '/documents',
  'F': '/folders',
  'B': '/binders',
  'W': '/workspaces',
  'QS': '/quicksearch'
};

/** Get entity base endpoint location depending on its kind.
 * @param {object} entity
 * @param {object} user - connected user (required only for views)
 * @return {string} base URL endpoint for web-service entity
 */
export const getEntityEndpoint = (entity, user) => {
  if (entity) {
    return entityKindMap[entity.EntityKind] || `/workspaces/${user}/views`;
  }
  return '';
}

/** Get entity identifier used for entity web-services
 * @param {object} entity 
 * @return {string} identifier of 'real' targeted entity
 */
export const getEntityIdentifier = (entity) => entity.IsShortcut ? entity.TargetEntityId : entity.Id;

/** Get entity kind 
 * @param {object} entity 
 * @return {string} Kind
 */
export const getEntityKind = ({ EntityKind }) => EntityKind;

/** Get entity generic route (ex : /binders/Z001234/sub)
 * @param {object} entity
 * @param {string} suffix - (optional) suffix endpoint
 * @param {string} user - (optional) user identifier
 * @returns {string} computed complete endpoint
 */
export const getEndpoint = (entity, suffix = null, user = null) => {

  const endpoint = `${getEntityEndpoint(entity, user)}/${getEntityIdentifier(entity)}`;
  if (suffix) return `${endpoint}/${suffix}`;
  return endpoint;
}

/** Get entity generic short route (ex : /B/Z001234)
 * @param {object} entity
 * @returns {string} computed short endpoint
 */
export const getEndpointShort = (entity) => `${getEntityKind(entity)}/${getEntityIdentifier(entity)}`;

/** STATE slice SELECTORS */

//state selector for config
export const selectConfig = (state) => state.config;

//state selector for JWT session token
export const selectToken = (state) => state.session.token;

//state selector for user identifier
export const getCurrentUserId = (state) => state.settings.User.Id;