import { waitForIt, noop } from 'zen-cerebellum';
import { restoreSession } from './auth';

//WAA : read local configuration
function fetchConfig() {
  return {
    type: 'CONFIG',
    api: {
      endpoint: "*/config.json",
      options: {
        restricted: false
      }
    }
  };
}

//WAA : read instances
function fetchInstances() {
  return {
    type: 'INSTANCES',
    api: {
      endpoint: "/instances",
      options: {
        restricted: false
      }
    }
  };
}

//RAA : load available instances
export function loadInstances() {

  return (dispatch, getState) => {

    const { instances } = getState();

    if (instances.length > 0) {
      return noop();
    }
    //only fetch instances if not already done
    return dispatch(fetchInstances());
  };
}

//RAA : initialize workflow
export function initFlow() {

  return (dispatch) => {

    return waitForIt(resolve => {
      //retrieve configuration file
      dispatch(fetchConfig()).then(({ brand }) => {

        //init branding asap
        if (brand) document.title = brand;

        //then try to restore session
        dispatch(restoreSession()).always(() => {
          //set promise as resolved
          resolve();
        });
      });
    });
  };
}
