import { nls } from "zen-lingual";
import { MESSAGE_NOTIFY, MESSAGES_CLEAR } from "../constants";

/** FSA : log a new message notification
  @param message (string) : text message to log
  @param title (string) : title of log message
  @param level (string) : gravity level (success, warning, danger, info)
*/
export function logMessage(message, title = "", level = "info") {
  return {
    type: MESSAGE_NOTIFY,
    payload: {
      message,
      title,
      level
    }
  };
}

//mapping from message level to gravity level
const messageLevelMap = {
  "1": "info",
  "2": "warning",
  "3": "danger"
};

/** FSA : notify an internal error
  @param error (object) : XHR failure error
*/
export function logInternalError(error) {
  //check if meta info or just a description
  const info = error.message.split("|");
  const hasMeta = info.length > 1;

  //get meta info and user friendly message
  const meta = hasMeta ? info[0] : "";
  //const text = hasMeta ? info[1] : error.message;

  //extract level and code from the infos
  const name = meta.split("-");
  const level = isNaN(name[0]) ? 3 : parseInt(name[0], 10);
  const code = isNaN(name[1]) ? 0 : parseInt(name[1], 10);

  //do nothing when zero code status
  if (code === 0) return;

  //translate them
  const msg = code ? nls(`messages.${code}`) : nls("core.error.default");
  const title = nls(`core.msgLevel.${level}`) + ` #${code}`;

  return logMessage(msg, title, messageLevelMap[level] || "danger");
}

//FSA : clear all message notifications
export function clearMessages() {
  return {
    type: MESSAGES_CLEAR
  };
}
